<?php

namespace Drupal\mbp\Layout;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Layout\LayoutDefault;

/**
 * Utility bootstrap class.
 */
class BootstrapColumns3 extends LayoutDefault {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'layout' => 'layout--33-33-33',
      'breakpoint' => 'md',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $configuration = $this->getConfiguration();

    $form['layout'] = [
      '#type' => 'select',
      '#title' => $this->t('Column Layout'),
      '#required' => TRUE,
      '#options' => [
        'layout--33-33-33' => $this->t('1/3 - 1/3 - 1/3'),
        'layout--25-50-25' => $this->t('1/4 - 1/2 - 1/4'),
        'layout--50-25-25' => $this->t('1/2 - 1/4 - 1/4'),
        'layout--25-25-50' => $this->t('1/4 - 1/4 - 1/2'),
        'layout--16-66-16' => $this->t('1/6 - 2/3 - 1/6'),
        'layout--66-16-16' => $this->t('2/3 - 1/6 - 1/6'),
        'layout--16-16-66' => $this->t('1/6 - 1/6 - 2/3'),
      ],
      '#default_value' => $configuration['layout'],
    ];

    $form['breakpoint'] = [
      '#type' => 'select',
      '#title' => $this->t('Column Breakpoint'),
      '#description' => $this->t('Select the minimum Bootstrap breakpoint size where columns will be displayed. Below this breakpoint, the row will collapse into a single column.'),
      '#required' => TRUE,
      '#options' => [
        'all' => $this->t('All'),
        'sm' => $this->t('Small'),
        'md' => $this->t('Medium'),
        'lg' => $this->t('Large'),
        'xl' => $this->t('Extra Large'),
      ],
      '#default_value' => $configuration['breakpoint'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['layout'] = $form_state->getValue('layout');
    $this->configuration['breakpoint'] = $form_state->getValue('breakpoint');
  }

}
